<?php

namespace Drupal\whatsapp_in\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * {@inheritdoc}
 */
class WhatsappForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'whatsapp_number_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['whatsapp.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('whatsapp.settings');
    $form['phone_number'] = [
      '#type' => 'tel',
      '#title' => $this->t('Mobile Number'),
      '#description' => $this->t('Enter the last 10 digits of your mobile number. The prefix +91 is automatically added.'),
      '#default_value' => substr($config->get('phone_number'), 3),
      '#maxlength' => 10,
      '#size' => 10,
      '#required' => TRUE,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
    $phone_number = $form_state->getValue('phone_number');
    // Check that the input contains exactly 10 digits.
    if (!preg_match('/^[0-9]{10}$/', $phone_number)) {
      $form_state->setErrorByName('phone_number', $this->t('Please enter exactly 10 digits for your mobile number.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $phone_number = $form_state->getValue('phone_number');
    $this->config('whatsapp.settings')
    // Prepend +91 before saving.
      ->set('phone_number', '+91' . $phone_number)
      ->save();
    parent::submitForm($form, $form_state);
  }

}
